@@ -1097,7 +1097,7 @@ static monster* _friendly(monster_type mt, int dur)
 {
     return create_monster(mgen_data(mt, BEH_FRIENDLY, you.pos(), MHITYOU,
                                     MG_AUTOFOE)
-                          .set_summoned(&you, dur, 0));
+                          .set_summoned(&you, 0, summ_dur(dur)));
 }
 
 static void _damaging_card(card_type card, int power,
@@ -1129,7 +1129,7 @@ static void _damaging_card(card_type card, int power,
                 return !mons.wont_attack()
                        && mons_is_threatening(mons)
                        && coinflip()
-                       && mons.corrode_equipment();
+                       && mons.corrode(&you);
             });
         }
         ztype = acidzaps[power_level];
@@ -1244,7 +1244,7 @@ static void _summon_demon_card(int power)
 
     if (!create_monster(mgen_data(dct, hostile ? BEH_HOSTILE : BEH_FRIENDLY,
                                   you.pos(), MHITYOU, MG_AUTOFOE)
-                        .set_summoned(&you, 5 - power_level, 0)))
+                        .set_summoned(&you, 0, summ_dur(5 - power_level))))
     {
         mpr("You see a puff of smoke.");
     }
@@ -1287,7 +1287,7 @@ static void _summon_dancing_weapon(int power)
     monster *mon =
         create_monster(
             mgen_data(MONS_DANCING_WEAPON, BEH_FRIENDLY, you.pos(), MHITYOU,
-                      MG_AUTOFOE).set_summoned(&you, power_level + 2, 0),
+                      MG_AUTOFOE).set_summoned(&you, 0, summ_dur(power_level + 2)),
             false);
 
     if (!mon)
@@ -1338,7 +1338,7 @@ static void _summon_dancing_weapon(int power)
     if (one_chance_in(3))
     {
         make_item_randart(wpn, true);
-        set_ident_flags(wpn, ISFLAG_KNOW_PROPERTIES| ISFLAG_KNOW_TYPE);
+        identify_item(wpn);
     }
 
     // Don't leave a trail of weapons behind. (Especially not randarts!)
@@ -1493,7 +1493,6 @@ static void _storm_card(int power)
     {
         bolt beam;
         beam.flavour           = BEAM_ELECTRICITY;
-        beam.is_tracer         = false;
         beam.is_explosion      = true;
         beam.glyph             = dchar_glyph(DCHAR_FIRED_BURST);
         beam.name              = "electrical discharge";
@@ -1563,7 +1562,7 @@ static void _degeneration_card(int power)
                if (mons.can_polymorph())
                {
                    mons.polymorph(PPT_LESS);
-                   mons.malmutate("");
+                   mons.malmutate(&you);
                }
                else
                {
@@ -1708,7 +1707,7 @@ void card_effect(card_type which_card,
         break;
 
     case CARD_SWINE:
-        if (transform(5 + power/10 + random2(power/10), transformation::pig, true))
+        if (transform(roll_dice(10, 10), transformation::pig, true))
             you.transform_uncancellable = true;
         else
             mpr("You feel a momentary urge to oink.");
