@@ -8,17 +8,22 @@
 
 #include "spl-monench.h"
 
+#include "actor.h"
 #include "beam.h"
 #include "coordit.h"
+#include "directn.h"
 #include "english.h" // apostrophise
 #include "env.h"
 #include "fight.h"
 #include "losglobal.h"
+#include "melee-attack.h"
 #include "message.h"
 #include "mon-tentacle.h"
 #include "spl-util.h"
 #include "stringutil.h" // make_stringf
 #include "terrain.h"
+#include "transform.h"
+#include "rltiles/tiledef-main.h"
 #include "view.h"
 
 int englaciate(coord_def where, int pow, actor *agent)
@@ -34,12 +39,8 @@ int englaciate(coord_def where, int pow, actor *agent)
     monster* mons = victim->as_monster();
 
     // Skip some ineligable monster categories
-    if (mons &&
-        (mons_is_conjured(mons->type) || mons_is_firewood(*mons)
-        || mons_is_tentacle_segment(mons->type)))
-    {
+    if (victim->is_peripheral() || never_harm_monster(agent, mons))
         return 0;
-    }
 
     if (victim->res_cold() > 0)
     {
@@ -90,15 +91,16 @@ spret cast_englaciation(int pow, bool fail)
 /** Corona a monster.
  *
  *  @param mons the monster to get a backlight.
+ *  @param source The actor responsible for this.
  *  @returns true if it got backlit (even if it was already).
  */
-bool backlight_monster(monster* mons)
+bool backlight_monster(monster* mons, const actor* source)
 {
     const mon_enchant bklt = mons->get_ench(ENCH_CORONA);
     const mon_enchant zin_bklt = mons->get_ench(ENCH_SILVER_CORONA);
     const int lvl = bklt.degree + zin_bklt.degree;
 
-    mons->add_ench(mon_enchant(ENCH_CORONA, 1));
+    mons->add_ench(mon_enchant(ENCH_CORONA, 1, source));
 
     if (lvl == 0)
         simple_monster_message(*mons, " is outlined in light.");
@@ -127,6 +129,17 @@ bool do_slow_monster(monster& mon, const actor* agent, int dur)
     return false;
 }
 
+bool silence_monster(monster& mon, const actor* agent, int dur)
+{
+    if (mon.add_ench(mon_enchant(ENCH_MUTE, 0, agent, dur)))
+    {
+        simple_monster_message(mon, " loses the ability to speak.");
+        return true;
+    }
+
+    return false;
+}
+
 bool enfeeble_monster(monster &mon, int pow)
 {
     const int res_margin = mon.check_willpower(&you, pow);
@@ -236,16 +249,14 @@ string describe_rimeblight_damage(int pow, bool terse)
                         shards_damage.num, shards_damage.size);
 }
 
-bool maybe_spread_rimeblight(monster& victim, int power, bool test_only)
+bool maybe_spread_rimeblight(monster& victim, int power)
 {
     if (!victim.has_ench(ENCH_RIMEBLIGHT)
-        && !mons_is_firewood(victim)
-        && !mons_is_conjured(victim.type)
-        && x_chance_in_y(2, 3)
+        && !victim.is_peripheral()
+        && !never_harm_monster(&you, victim)
         && you.see_cell_no_trans(victim.pos()))
     {
-        if (!test_only)
-            apply_rimeblight(victim, power);
+        apply_rimeblight(victim, power);
         return true;
     }
 
@@ -257,7 +268,7 @@ bool apply_rimeblight(monster& victim, int power, bool quiet)
     if (victim.has_ench(ENCH_RIMEBLIGHT))
         return false;
 
-    int duration = (random_range(7, 11) + div_rand_round(power, 30))
+    int duration = (random_range(8, 12) + div_rand_round(power, 30))
                     * BASELINE_DELAY;
     victim.add_ench(mon_enchant(ENCH_RIMEBLIGHT, 0, &you, duration));
     victim.props[RIMEBLIGHT_POWER_KEY] = power;
@@ -341,20 +352,7 @@ spret cast_sign_of_ruin(actor& caster, coord_def target, int duration, bool chec
         return spret::abort;
 
     // Show animation
-    for (int i = 2; i >= 0; --i)
-    {
-        for (distance_iterator di(target, false, false, i); di; ++di)
-        {
-            if (grid_distance(target, *di) == i && !feat_is_solid(env.grid(*di))
-                && you.see_cell_no_trans(*di))
-            {
-                flash_tile(*di, random_choose(DARKGRAY, RED), 0);
-            }
-        }
-
-        animation_delay(50, true);
-        view_clear_overlays();
-    }
+    draw_ring_animation(target, 2, DARKGRAY, RED);
 
     // Apply signs
     for (actor* act : targets)
@@ -376,3 +374,139 @@ spret cast_sign_of_ruin(actor& caster, coord_def target, int duration, bool chec
 
     return spret::success;
 }
+
+spret cast_percussive_tempering(const actor& caster, monster& target, int power,
+                                bool fail)
+{
+    fail_check();
+
+    if (you.can_see(target))
+    {
+        mprf("A magical hammer augments %s in a flurry of sparks and slag.",
+             target.name(DESC_THE).c_str());
+    }
+
+    flash_tile(target.pos(), WHITE, 0, TILE_BOLT_PERCUSSIVE_TEMPERING);
+
+    bolt shockwave;
+    shockwave.set_agent(&caster);
+    shockwave.attitude = caster.temp_attitude();
+    shockwave.source = target.pos();
+    shockwave.target = target.pos();
+    shockwave.is_explosion = true;
+    shockwave.ex_size = 1;
+    shockwave.origin_spell = SPELL_PERCUSSIVE_TEMPERING;
+    zappy(ZAP_PERCUSSIVE_TEMPERING, power, true, shockwave);
+    shockwave.explode(true, true);
+
+    target.heal(roll_dice(3, 10));
+    target.add_ench(mon_enchant(ENCH_TEMPERED, 0, &caster, random_range(70, 100)));
+
+    // Give a small bit of extra duration if we're about to time out, just to
+    // avoid the sad feeling of buffing a monster who immediately vanishes.
+    if (target.has_ench(ENCH_SUMMON_TIMER))
+    {
+        mon_enchant dur = target.get_ench(ENCH_SUMMON_TIMER);
+        if (dur.duration < 50)
+        {
+            dur.duration += random_range(30, 50);
+            target.update_ench(dur);
+        }
+    }
+
+    return spret::success;
+}
+
+bool is_valid_tempering_target(const monster& mon, const actor& caster)
+{
+    if (!mon.was_created_by(caster) || mon.has_ench(ENCH_TEMPERED))
+        return false;
+
+    mon_enchant summ = mon.get_ench(ENCH_SUMMON);
+    if (summ.degree > 0)
+    {
+        const spell_type spell = (spell_type)summ.degree;
+        // XXX: Bomblets are marked as created by the player cast of Monarch
+        //      Bomb in order to track all detontation targets, but should *not*
+        //      count as valid targets for Percussive Tempering despite this.
+        if (!!(get_spell_disciplines(spell) & spschool::forgecraft))
+            return mon.type != MONS_BOMBLET && mon.type != MONS_BLAZEHEART_CORE;
+    }
+
+    return false;
+}
+
+// Perform a forcible attack at a weighted random space around this actor.
+// Spaces without an actor are 1/7th as likely to be chosen as one with an
+// actor (so if you are adjacent to a single monster, you have a 50% chance to
+// attack them and a 50% chance to whiff).
+//
+// Actor friendliness doesn't matter - you are just as likely to attack allies
+// as enemies, though gods won't penance you for this action since it's not your
+// fault. The allies themselves may not be so generous!
+void do_vexed_attack(actor& attacker, bool always_hit_ally)
+{
+    const bool has_attacks = attacker.is_player() ? true
+                                : mons_has_attacks(*attacker.as_monster(), true);
+
+    vector<coord_def> empty_space;
+    vector<actor*> targs;
+
+    for (adjacent_iterator ai(attacker.pos()); ai; ++ai)
+    {
+        if (actor* targ = actor_at(*ai))
+        {
+            if (!always_hit_ally || mons_aligned(&attacker, targ))
+                targs.push_back(targ);
+        }
+        else if (!always_hit_ally)
+            empty_space.push_back(*ai);
+    }
+
+    // If we've been told to attack an ally, but none are around, just hit the floor.
+    if (always_hit_ally && targs.empty())
+        empty_space.push_back(attacker.pos());
+
+    // Decide whether to attack empty space or an actor
+    const int total_weight = empty_space.size() + targs.size() * 7;
+    if (x_chance_in_y(empty_space.size(), total_weight))
+    {
+        coord_def pos = empty_space[random2(empty_space.size())];
+        string targ_desc = (attacker.airborne() && feat_has_solid_floor(env.grid(pos))
+                            && coinflip()) ? "the ceiling"
+                            : feature_description_at(pos, false, DESC_THE);
+        if (you.can_see(attacker))
+        {
+            mprf("%s %s %s!",
+                    attacker.name(DESC_THE).c_str(),
+                    has_attacks ? attacker.is_monster() ? "attacks" : "attack"
+                                : "glares at",
+                    targ_desc.c_str());
+        }
+
+        if (attacker.is_monster())
+            attacker.as_monster()->lose_energy(EUT_ATTACK);
+    }
+    else
+    {
+        ASSERT(!targs.empty());
+        actor* victim = targs[random2(targs.size())];
+        if (has_attacks)
+        {
+            melee_attack atk(&attacker, victim);
+            // The player is deliberately allowed to attack their allies.
+            atk.never_prompt = true;
+            atk.launch_attack_set();
+        }
+        else
+        {
+            if (you.can_see(attacker))
+            {
+                mprf("%s glares at %s!",
+                        attacker.name(DESC_THE).c_str(),
+                        victim->name(DESC_THE).c_str());
+            }
+            attacker.as_monster()->lose_energy(EUT_ATTACK);
+        }
+    }
+}
